@@ -121,41 +121,15 @@ def register_admin(model_admin):
     from django.utils.safestring import mark_safe
     from django import template
     from django.contrib.contenttypes.models import ContentType
-    
+
     old_render_change_form = model_admin.render_change_form
-    
-    # this is exactly the same as render_change_form, except it calls old_has_change_permission
-    # This is necessary to hide "Save (...)" buttons 
+
     @wraps(old_render_change_form)
-    def new_render_change_form(self, request, context, add=False, change=False, form_url='', obj=None):
-        opts = self.model._meta
-        app_label = opts.app_label
-        ordered_objects = opts.get_ordered_objects()
-        context.update({
-            'add': add,
-            'change': change,
-            'has_add_permission': self.has_add_permission(request),
-            'has_change_permission': old_has_change_permission(self, request, obj),
-            'has_delete_permission': self.has_delete_permission(request, obj),
-            'has_file_field': True, # FIXME - this should check if form or formsets have a FileField,
-            'has_absolute_url': hasattr(self.model, 'get_absolute_url'),
-            'ordered_objects': ordered_objects,
-            'form_url': mark_safe(form_url),
-            'opts': opts,
-            'content_type_id': ContentType.objects.get_for_model(self.model).id,
-            'save_as': self.save_as,
-            'save_on_top': self.save_on_top,
-            'root_path': self.admin_site.root_path,
+    def new_render_change_form(self, request, context, obj=None, *args, **kwargs):
+        res = old_render_change_form(self, request, context, *args, **kwargs)
+        res.context_data.update({
+            'has_change_permission': old_has_change_permission(self, request, obj)
         })
-        if add and self.add_form_template is not None:
-            form_template = self.add_form_template
-        else:
-            form_template = self.change_form_template
-        context_instance = template.RequestContext(request, current_app=self.admin_site.name)
-        return render_to_response(form_template or [
-            "admin/%s/%s/change_form.html" % (app_label, opts.object_name.lower()),
-            "admin/%s/change_form.html" % app_label,
-            "admin/change_form.html"
-        ], context, context_instance=context_instance)
-        
+        return res
+
     model_admin.render_change_form = new_render_change_form
